@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_certificatemanager._jsii
 import aws_cdk.aws_cloudfront._jsii
@@ -23,9 +23,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-cloudfront-authorization",
-    "1.1.2",
+    "1.1.4",
     __name__[0:-6],
-    "cdk-cloudfront-authorization@1.1.2.jsii.tgz",
+    "cdk-cloudfront-authorization@1.1.4.jsii.tgz",
 )
 
 __all__ = [
